====
Team
====

Quik is written and maintained by the Quik Team and various contributors:

Lead Developer
==============

- Thiago Avelino <thiago@avelino.xxx>


Contributors
============

.. and more. If I missed you, please fork, add your name and send a pull request.
